# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`landscape`](#landscape): Installs the landscape server.
* [`landscape::apache`](#landscape--apache): Manages the apache specific configuration.
* [`landscape::client`](#landscape--client): Manages a client for landscape.
* [`landscape::db`](#landscape--db): Manages the db for landscape.
* [`landscape::pam`](#landscape--pam): Manages the moinmoin plugin for ldap integration.

## Classes

### <a name="landscape"></a>`landscape`

Installs the landscape server.

#### Parameters

The following parameters are available in the `landscape` class:

* [`servername`](#-landscape--servername)
* [`license`](#-landscape--license)
* [`version`](#-landscape--version)
* [`ssl_cert_path`](#-landscape--ssl_cert_path)
* [`ssl_key_path`](#-landscape--ssl_key_path)
* [`ssl_chain_path`](#-landscape--ssl_chain_path)
* [`enable_pam`](#-landscape--enable_pam)

##### <a name="-landscape--servername"></a>`servername`

Data type: `String`

The server's url.

##### <a name="-landscape--license"></a>`license`

Data type: `Optional[String]`

Contains the license file contents.

Default value: `undef`

##### <a name="-landscape--version"></a>`version`

Data type: `String`

The server version to install landscape.

Default value: `'19.10'`

##### <a name="-landscape--ssl_cert_path"></a>`ssl_cert_path`

Data type: `String`

The ssl cert path for apache.
The default cert is installed by the landscape package.

Default value: `'/etc/ssl/certs/landscape_server.pem'`

##### <a name="-landscape--ssl_key_path"></a>`ssl_key_path`

Data type: `String`

The key to the cert for apache.

Default value: `'/etc/ssl/private/landscape_server.key'`

##### <a name="-landscape--ssl_chain_path"></a>`ssl_chain_path`

Data type: `String`

The chain for the apache certs.

Default value: `'/etc/ssl/certs/landscape_server_ca.crt'`

##### <a name="-landscape--enable_pam"></a>`enable_pam`

Data type: `Boolean`

Uses PAM to authenticate users. Note, this module does not
setup PAM for authentication.  It only uses the existing pam
configuration to authenticate users.

Default value: `false`

### <a name="landscape--apache"></a>`landscape::apache`

Manages the apache specific configuration.

#### Parameters

The following parameters are available in the `landscape::apache` class:

* [`servername`](#-landscape--apache--servername)
* [`ssl_cert_path`](#-landscape--apache--ssl_cert_path)
* [`ssl_key_path`](#-landscape--apache--ssl_key_path)
* [`ssl_chain_path`](#-landscape--apache--ssl_chain_path)

##### <a name="-landscape--apache--servername"></a>`servername`

Data type: `String`

The server's url.

##### <a name="-landscape--apache--ssl_cert_path"></a>`ssl_cert_path`

Data type: `String`

The ssl cert path for apache.

##### <a name="-landscape--apache--ssl_key_path"></a>`ssl_key_path`

Data type: `String`

The key to the cert for apache.

##### <a name="-landscape--apache--ssl_chain_path"></a>`ssl_chain_path`

Data type: `String`

The chain for the apache certs.

### <a name="landscape--client"></a>`landscape::client`

Manages a client for landscape.

#### Parameters

The following parameters are available in the `landscape::client` class:

* [`server_url`](#-landscape--client--server_url)
* [`ensure`](#-landscape--client--ensure)
* [`server_cert`](#-landscape--client--server_cert)
* [`server_cert_path`](#-landscape--client--server_cert_path)
* [`copy_server_cert`](#-landscape--client--copy_server_cert)
* [`account_name`](#-landscape--client--account_name)
* [`computer_title`](#-landscape--client--computer_title)
* [`enable_script_exec`](#-landscape--client--enable_script_exec)
* [`script_users`](#-landscape--client--script_users)
* [`extra_config`](#-landscape--client--extra_config)

##### <a name="-landscape--client--server_url"></a>`server_url`

Data type: `String`

The landscape server's FQDN.

##### <a name="-landscape--client--ensure"></a>`ensure`

Data type: `String`

The following states.
* present - software installed and configured.
* absent  - the software and configuration removed

Default value: `'present'`

##### <a name="-landscape--client--server_cert"></a>`server_cert`

Data type: `Optional[String]`

The landscape server certificate contents.

Default value: `undef`

##### <a name="-landscape--client--server_cert_path"></a>`server_cert_path`

Data type: `String`

The full path to the server's certificate.

Default value: `'/etc/landscape/server.pem'`

##### <a name="-landscape--client--copy_server_cert"></a>`copy_server_cert`

Data type: `Boolean`

If set to false, assumes the certificate is already copied.
If set to true, uses the server_cert to fill the contents of the cert.

Default value: `true`

##### <a name="-landscape--client--account_name"></a>`account_name`

Data type: `String`

The account this computer belongs to.

Default value: `'standalone'`

##### <a name="-landscape--client--computer_title"></a>`computer_title`

Data type: `String`

The title of this computer.

Default value: `$facts['networking']['hostname']`

##### <a name="-landscape--client--enable_script_exec"></a>`enable_script_exec`

Data type: `Boolean`

Set to true if landscape can run scripts remotely.

Default value: `false`

##### <a name="-landscape--client--script_users"></a>`script_users`

Data type: `String`

A string of a comma separated list of users that can run scripts.

Default value: `'root'`

##### <a name="-landscape--client--extra_config"></a>`extra_config`

Data type: `Hash`

A hash containing additional configuration parameters.

Default value: `{}`

### <a name="landscape--db"></a>`landscape::db`

Manages the db for landscape.

#### Parameters

The following parameters are available in the `landscape::db` class:

* [`version`](#-landscape--db--version)

##### <a name="-landscape--db--version"></a>`version`

Data type: `String`

The version of the postgresql database to install.

Default value: `'9.6'`

### <a name="landscape--pam"></a>`landscape::pam`

Manages the moinmoin plugin for ldap integration.

